@@ -67,7 +67,7 @@ test_that("LDA is working", {
         print(lda),
         paste0("\nCall:\n",
                "textmodel_lda(x = dfmt, k = 5, max_iter = 200)\n\n",
-               "5 topics; 500 documents; 22,605 features."),
+               "5 topics; 500 documents; 22,544 features."),
         fixed = TRUE
     )
     expect_equal(
@@ -84,23 +84,33 @@ test_that("LDA is working", {
 test_that("alpha and beta work", {
 
     lda <- textmodel_lda(dfmt, max_iter = 200)
-    expect_equal(lda$alpha, 0.5)
-    expect_equal(lda$beta, 0.1)
+    expect_equal(lda$alpha, rep(0.5, 10))
+    expect_equal(lda$beta, rep(0.1, 10))
 
     lda2 <- textmodel_lda(dfmt, alpha = 0.7, beta = 0.2, max_iter = 200)
-    expect_equal(lda2$alpha, 0.7)
-    expect_equal(lda2$beta, 0.2)
+    expect_equal(lda2$alpha, rep(0.7, 10))
+    expect_equal(lda2$beta, rep(0.2, 10))
 
     expect_error(
         textmodel_lda(dfmt, alpha = -0.1),
         "The value of alpha must be between 0 and Inf"
     )
 
+    expect_error(
+    	textmodel_lda(dfmt, alpha = rep(0.5, 5)),
+    	"The length of alpha must be 10"
+    )
+
     expect_error(
         textmodel_lda(dfmt, beta = -0.1),
         "The value of beta must be between 0 and Inf"
     )
 
+    expect_error(
+    	textmodel_lda(dfmt, beta = rep(0.1, 5)),
+    	"The length of beta must be 10"
+    )
+
 })
 
 test_that("verbose works", {
@@ -231,8 +241,8 @@ test_that("select and min_prob are working", {
     )
 
     expect_equal(
-        topics(lda)[1:10],
-        topics(lda, select = paste0("topic", 1:5))[1:10]
+        topics(lda)[10:20],
+        topics(lda, select = paste0("topic", 1:5))[10:20]
     )
 
     expect_equal(
@@ -289,7 +299,7 @@ test_that("distributed LDA works", {
     options(seededlda_threads = "a")
     expect_error(
         textmodel_lda(dfmt, k = 5, batch_size = 0.2, max_iter = 200, verbose = FALSE),
-        'getOption("seededlda_threads", -1) must be coercible to integer', fixed = TRUE
+        'seededlda_threads must be an integer', fixed = TRUE
     )
     options(seededlda_threads = -1) # use all threads
     expect_silent(
